@@ -78,19 +78,17 @@ class ZoneName {
         "Africa/Brazzaville", "Africa_Western", "Africa/Lagos",
         "Africa/Bujumbura", "Africa_Central", "Africa/Maputo",
         "Africa/Cairo", "Europe_Eastern", "Europe/Bucharest",
-        "Africa/Casablanca", "Europe_Western", "Atlantic/Canary",
         "Africa/Ceuta", "Europe_Central", "Europe/Paris",
         "Africa/Conakry", "GMT", "Atlantic/Reykjavik",
         "Africa/Dakar", "GMT", "Atlantic/Reykjavik",
         "Africa/Dar_es_Salaam", "Africa_Eastern", "Africa/Nairobi",
         "Africa/Djibouti", "Africa_Eastern", "Africa/Nairobi",
         "Africa/Douala", "Africa_Western", "Africa/Lagos",
-        "Africa/El_Aaiun", "Europe_Western", "Atlantic/Canary",
         "Africa/Freetown", "GMT", "Atlantic/Reykjavik",
         "Africa/Gaborone", "Africa_Central", "Africa/Maputo",
         "Africa/Harare", "Africa_Central", "Africa/Maputo",
         "Africa/Johannesburg", "Africa_Southern", "Africa/Johannesburg",
-        "Africa/Juba", "Africa_Eastern", "Africa/Nairobi",
+        "Africa/Juba", "Africa_Central", "Africa/Maputo",
         "Africa/Kampala", "Africa_Eastern", "Africa/Nairobi",
         "Africa/Khartoum", "Africa_Central", "Africa/Maputo",
         "Africa/Kigali", "Africa_Central", "Africa/Maputo",
@@ -113,7 +111,7 @@ class ZoneName {
         "Africa/Nouakchott", "GMT", "Atlantic/Reykjavik",
         "Africa/Ouagadougou", "GMT", "Atlantic/Reykjavik",
         "Africa/Porto-Novo", "Africa_Western", "Africa/Lagos",
-        "Africa/Sao_Tome", "Africa_Western", "Africa/Lagos",
+        "Africa/Sao_Tome", "GMT", "Atlantic/Reykjavik",
         "Africa/Timbuktu", "GMT", "Atlantic/Reykjavik",
         "Africa/Tripoli", "Europe_Eastern", "Europe/Bucharest",
         "Africa/Tunis", "Europe_Central", "Europe/Paris",
@@ -133,7 +131,7 @@ class ZoneName {
         "America/Argentina/Rio_Gallegos", "Argentina", "America/Buenos_Aires",
         "America/Argentina/Salta", "Argentina", "America/Buenos_Aires",
         "America/Argentina/San_Juan", "Argentina", "America/Buenos_Aires",
-        "America/Argentina/San_Luis", "Argentina_Western", "America/Argentina/San_Luis",
+        "America/Argentina/San_Luis", "Argentina", "America/Buenos_Aires",
         "America/Argentina/Tucuman", "Argentina", "America/Buenos_Aires",
         "America/Argentina/Ushuaia", "Argentina", "America/Buenos_Aires",
         "America/Aruba", "Atlantic", "America/Halifax",
@@ -167,7 +165,7 @@ class ZoneName {
         "America/Cuiaba", "Amazon", "America/Manaus",
         "America/Curacao", "Atlantic", "America/Halifax",
         "America/Danmarkshavn", "GMT", "Atlantic/Reykjavik",
-        "America/Dawson", "America_Pacific", "America/Los_Angeles",
+        "America/Dawson", "America_Mountain", "America/Denver",
         "America/Dawson_Creek", "America_Mountain", "America/Denver",
         "America/Denver", "America_Mountain", "America/Denver",
         "America/Detroit", "America_Eastern", "America/New_York",
@@ -239,6 +237,7 @@ class ZoneName {
         "America/North_Dakota/Beulah", "America_Central", "America/Chicago",
         "America/North_Dakota/Center", "America_Central", "America/Chicago",
         "America/North_Dakota/New_Salem", "America_Central", "America/Chicago",
+        "America/Nuuk", "Greenland_Western", "America/Godthab",
         "America/Ojinaga", "America_Central", "America/Chicago",
         "America/Panama", "America_Eastern", "America/New_York",
         "America/Pangnirtung", "America_Eastern", "America/New_York",
@@ -279,14 +278,14 @@ class ZoneName {
         "America/Tortola", "Atlantic", "America/Halifax",
         "America/Vancouver", "America_Pacific", "America/Los_Angeles",
         "America/Virgin", "Atlantic", "America/Halifax",
-        "America/Whitehorse", "America_Pacific", "America/Los_Angeles",
+        "America/Whitehorse", "America_Mountain", "America/Denver",
         "America/Winnipeg", "America_Central", "America/Chicago",
         "America/Yakutat", "Alaska", "America/Juneau",
         "America/Yellowknife", "America_Mountain", "America/Denver",
         "Antarctica/Casey", "Casey", "Antarctica/Casey",
         "Antarctica/Davis", "Davis", "Antarctica/Davis",
         "Antarctica/DumontDUrville", "DumontDUrville", "Antarctica/DumontDUrville",
-        "Antarctica/Macquarie", "Macquarie", "Antarctica/Macquarie",
+        "Antarctica/Macquarie", "Australia_Eastern", "Australia/Sydney",
         "Antarctica/Mawson", "Mawson", "Antarctica/Mawson",
         "Antarctica/McMurdo", "New_Zealand", "Pacific/Auckland",
         "Antarctica/Rothera", "Rothera", "Antarctica/Rothera",
@@ -313,7 +312,7 @@ class ZoneName {
         "Asia/Brunei", "Brunei", "Asia/Brunei",
         "Asia/Calcutta", "India", "Asia/Calcutta",
         "Asia/Chita", "Yakutsk", "Asia/Yakutsk",
-        "Asia/Choibalsan", "Choibalsan", "Asia/Choibalsan",
+        "Asia/Choibalsan", "Mongolia", "Asia/Ulaanbaatar",
         "Asia/Chongqing", "China", "Asia/Shanghai",
         "Asia/Chungking", "China", "Asia/Shanghai",
         "Asia/Colombo", "India", "Asia/Calcutta",
@@ -359,9 +358,10 @@ class ZoneName {
         "Asia/Oral", "Kazakhstan_Western", "Asia/Aqtobe",
         "Asia/Phnom_Penh", "Indochina", "Asia/Bangkok",
         "Asia/Pontianak", "Indonesia_Western", "Asia/Jakarta",
-        "Asia/Pyongyang", "Pyongyang", "Asia/Pyongyang",
+        "Asia/Pyongyang", "Korea", "Asia/Seoul",
         "Asia/Qatar", "Arabian", "Asia/Riyadh",
-        "Asia/Qyzylorda", "Kazakhstan_Eastern", "Asia/Almaty",
+        "Asia/Qostanay", "Kazakhstan_Eastern", "Asia/Almaty",
+        "Asia/Qyzylorda", "Kazakhstan_Western", "Asia/Aqtobe",
         "Asia/Rangoon", "Myanmar", "Asia/Rangoon",
         "Asia/Riyadh", "Arabian", "Asia/Riyadh",
         "Asia/Saigon", "Indochina", "Asia/Bangkok",
@@ -436,7 +436,7 @@ class ZoneName {
         "Canada/Newfoundland", "Newfoundland", "America/St_Johns",
         "Canada/Pacific", "America_Pacific", "America/Los_Angeles",
         "Canada/Saskatchewan", "America_Central", "America/Chicago",
-        "Canada/Yukon", "America_Pacific", "America/Los_Angeles",
+        "Canada/Yukon", "America_Mountain", "America/Denver",
         "Chile/Continental", "Chile", "America/Santiago",
         "Chile/EasterIsland", "Easter", "Pacific/Easter",
         "Cuba", "Cuba", "America/Havana",
@@ -502,7 +502,7 @@ class ZoneName {
         "Europe/Vatican", "Europe_Central", "Europe/Paris",
         "Europe/Vienna", "Europe_Central", "Europe/Paris",
         "Europe/Vilnius", "Europe_Eastern", "Europe/Bucharest",
-        "Europe/Volgograd", "Moscow", "Europe/Moscow",
+        "Europe/Volgograd", "Volgograd", "Europe/Volgograd",
         "Europe/Warsaw", "Europe_Central", "Europe/Paris",
         "Europe/Zagreb", "Europe_Central", "Europe/Paris",
         "Europe/Zaporozhye", "Europe_Eastern", "Europe/Bucharest",
@@ -707,6 +707,7 @@ class ZoneName {
         "Europe_Central", "RS", "Europe/Belgrade",
         "Europe_Central", "SE", "Europe/Stockholm",
         "Europe_Central", "SI", "Europe/Ljubljana",
+        "Europe_Central", "SJ", "Arctic/Longyearbyen",
         "Europe_Central", "SK", "Europe/Bratislava",
         "Europe_Central", "SM", "Europe/San_Marino",
         "Europe_Central", "TN", "Africa/Tunis",
@@ -868,7 +869,6 @@ class ZoneName {
         "Asia/Bahrain", "Asia/Qatar",
         "Asia/Brunei", "Asia/Kuching",
         "Asia/Calcutta", "Asia/Kolkata",
-        "Asia/Choibalsan", "Asia/Ulaanbaatar",
         "Asia/Chongqing", "Asia/Shanghai",
         "Asia/Chungking", "Asia/Shanghai",
         "Asia/Dacca", "Asia/Dhaka",
@@ -908,8 +908,6 @@ class ZoneName {
         "Brazil/DeNoronha", "America/Noronha",
         "Brazil/East", "America/Sao_Paulo",
         "Brazil/West", "America/Manaus",
-        "CET", "Europe/Brussels",
-        "CST6CDT", "America/Chicago",
         "Canada/Atlantic", "America/Halifax",
         "Canada/Central", "America/Winnipeg",
         "Canada/Eastern", "America/Toronto",
@@ -921,9 +919,6 @@ class ZoneName {
         "Chile/Continental", "America/Santiago",
         "Chile/EasterIsland", "Pacific/Easter",
         "Cuba", "America/Havana",
-        "EET", "Europe/Athens",
-        "EST", "America/Panama",
-        "EST5EDT", "America/New_York",
         "Egypt", "Africa/Cairo",
         "Eire", "Europe/Dublin",
         "Etc/GMT+0", "Etc/GMT",
@@ -966,7 +961,6 @@ class ZoneName {
         "GMT-0", "Etc/GMT",
         "GMT0", "Etc/GMT",
         "Greenwich", "Etc/GMT",
-        "HST", "Pacific/Honolulu",
         "Hongkong", "Asia/Hong_Kong",
         "Iceland", "Africa/Abidjan",
         "Indian/Antananarivo", "Africa/Nairobi",
@@ -983,9 +977,6 @@ class ZoneName {
         "Japan", "Asia/Tokyo",
         "Kwajalein", "Pacific/Kwajalein",
         "Libya", "Africa/Tripoli",
-        "MET", "Europe/Brussels",
-        "MST", "America/Phoenix",
-        "MST7MDT", "America/Denver",
         "Mexico/BajaNorte", "America/Tijuana",
         "Mexico/BajaSur", "America/Mazatlan",
         "Mexico/General", "America/Mexico_City",
@@ -996,7 +987,6 @@ class ZoneName {
         "NZ-CHAT", "Pacific/Chatham",
         "Navajo", "America/Denver",
         "PRC", "Asia/Shanghai",
-        "PST8PDT", "America/Los_Angeles",
         "Pacific/Chuuk", "Pacific/Port_Moresby",
         "Pacific/Enderbury", "Pacific/Kanton",
         "Pacific/Funafuti", "Pacific/Tarawa",
@@ -1033,7 +1023,6 @@ class ZoneName {
         "UTC", "Etc/UTC",
         "Universal", "Etc/UTC",
         "W-SU", "Europe/Moscow",
-        "WET", "Europe/Lisbon",
         "Zulu", "Etc/UTC",
     };
 
